@@ -1,6 +1,7 @@
-import pandas as pd
 import logging
 
+import pandas as pd
+
 logging.basicConfig()
 logger = logging.getLogger(__name__)
 
@@ -8,19 +9,28 @@ logger = logging.getLogger(__name__)
 def downsample(df, max_rows=0, max_columns=0, max_bytes=0):
     """Return a subset of the dataframe that fits the limits"""
     org_rows, org_columns, org_bytes = len(df.index), len(df.columns), df.values.nbytes
-    df = _downsample(df, max_rows=max_rows, max_columns=max_columns, max_bytes=max_bytes)
+    df = _downsample(
+        df, max_rows=max_rows, max_columns=max_columns, max_bytes=max_bytes
+    )
 
     if len(df.index) < org_rows or len(df.columns) < org_columns:
         reasons = []
         if org_rows > max_rows > 0:
-            reasons.append('maxRows={}'.format(max_rows))
+            reasons.append("maxRows={}".format(max_rows))
         if org_columns > max_columns > 0:
-            reasons.append('maxColumns={}'.format(max_columns))
+            reasons.append("maxColumns={}".format(max_columns))
         if org_bytes > max_bytes > 0:
-            reasons.append('nbytes={}>{}=maxBytes'.format(org_bytes, max_bytes))
+            reasons.append("nbytes={}>{}=maxBytes".format(org_bytes, max_bytes))
 
-        logger.warning('showing {}x{} of {}x{} as {}. See https://mwouts.github.io/itables/#downsampling'.format(
-            len(df.index), len(df.columns), org_rows, org_columns, ' and '.join(reasons)))
+        logger.warning(
+            "showing {}x{} of {}x{} as {}. See https://mwouts.github.io/itables/#downsampling".format(
+                len(df.index),
+                len(df.columns),
+                org_rows,
+                org_columns,
+                " and ".join(reasons),
+            )
+        )
 
     return df
 
@@ -61,7 +71,7 @@ def _downsample(df, max_rows=0, max_columns=0, max_bytes=0):
 
         # max_product < 1.0:
         df = df.iloc[:1, :1]
-        df.iloc[0, 0] = '...'
+        df.iloc[0, 0] = "..."
         return df
 
     return df
